@@ -17,7 +17,7 @@
  * GNU Lesser General Public License for more details.
  *
  * You should have received a copy of the GNU Lesser General Public
- * License along with this library.  If not, see <http://www.gnu.org/licenses/>.
+ * License along with this library.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef LIBKGAPI2_CALENDARCREATEJOB_H
@@ -66,7 +66,7 @@ class KGAPICALENDAR_EXPORT CalendarCreateJob : public KGAPI2::CreateJob
     /**
      * @brief Destructor
      */
-    virtual ~CalendarCreateJob();
+    ~CalendarCreateJob() override;
 
   protected:
 
